function [L2err,Labs,hmesh] = L2Itpr(Mesh,UHandle)

    n_elem = size(Mesh.Elements,1); 
    QuadRule = P7O6(); % Gaussian Quadrature used

    n_pts = size(QuadRule.w,1);

    % Shape functions
    N = shap_LFE(QuadRule.x);

    L2err = 0.0;
    Labs = 0.0;

%Computation of integral error square in each of the triangular element

for i = 1:n_elem
    idx = Mesh.Elements(i,:);
    Vertices = Mesh.Coordinates(idx,:);
    
    P1 = Vertices(1,:);
    P2 = Vertices(2,:);
    P3 = Vertices(3,:);
    
    % mesh size information extracted for only one triangle
    if (i==1)
        hmesh1 = sqrt((P2 - P1)*(P2 - P1)');
        hmesh2 = sqrt((P3 - P2)*(P3 - P2)');
        hmesh3 = sqrt((P1 - P3)*(P1 - P3)');
        
        hmesh = max([hmesh1 hmesh2 hmesh3]);
    end
    
    % end of mesh size information
    
    %nodal value of the function in each of the vertices of triangle
    W = UHandle(Vertices(:,1),Vertices(:,2));
    
    % transformation of standard triangle [0 0;1 0;0 1] into required
    % triangle
    bK = P1;
    BK = [ P2 - P1 ; P3 - P1 ];
    det_BK = abs(det(BK));
  
    x = QuadRule.x*BK+ones(n_pts,1)*bK;
    
    %end of transformation
   
    Fval = UHandle(x(:,1),x(:,2)); %Function value on the triangle
    
    %Linear Interpolation value on the triangle
    Gval = W(1,1)*N(:,1)+W(2,1)*N(:,2)+W(3,1)*N(:,3);
    
    % L2 norm square of error computed
    L2err = L2err + ((sum(QuadRule.w.*((Fval- Gval)).^2))*det_BK);
    
    %L2 norm square of actual function computed
    Labs = Labs + ((sum((QuadRule.w.*(Fval)).^2))*det_BK);
    
end;

L2err = sqrt(L2err); %Obtaining final L2 norm
Labs = sqrt(Labs);
